@@ -172,6 +172,7 @@ _POSITION_ACTUATORS_V2020 = [
 # pylint: enable=bad-whitespace
 
 _UPRIGHT_POS = (0.0, 0.0, 0.94)
+_UPRIGHT_POS_V2020 = (0.0, 0.0, 1.143)
 _UPRIGHT_QUAT = (0.859, 1.0, 1.0, 0.859)
 
 # Height of head above which the humanoid is considered standing.
@@ -204,6 +205,17 @@ class _CMUHumanoidBase(legacy_base.Walker, metaclass=abc.ABCMeta):
 
     if include_face:
       head = self._mjcf_root.find('body', 'head')
+      head.add(
+          'geom',
+          type='capsule',
+          name='face',
+          size=(0.065, 0.014),
+          pos=(0.000341465, 0.048184, 0.01),
+          quat=(0.717887, 0.696142, -0.00493334, 0),
+          mass=0.,
+          contype=0,
+          conaffinity=0)
+
       face_forwardness = head.pos[1]-.02
       head_geom = self._mjcf_root.find('geom', 'head')
       nose_size = head_geom.size[0] / 4.75
@@ -223,7 +235,8 @@ class _CMUHumanoidBase(legacy_base.Walker, metaclass=abc.ABCMeta):
   def _build_observables(self):
     return CMUHumanoidObservables(self)
 
-  @abc.abstractproperty
+  @property
+  @abc.abstractmethod
   def _xml_path(self):
     raise NotImplementedError
 
@@ -415,6 +428,10 @@ class CMUHumanoidPositionControlledV2020(CMUHumanoidPositionControlled):
     super()._build(
         model_version='2020', scale_default=True, include_face=True, **kwargs)
 
+  @property
+  def upright_pose(self):
+    return base.WalkerPose(xpos=_UPRIGHT_POS_V2020, xquat=_UPRIGHT_QUAT)
+
 
 class CMUHumanoidObservables(legacy_base.WalkerObservables):
   """Observables for the Humanoid."""
