@@ -50,7 +50,7 @@ class FakeArrayObservationEnvironment(dm_env.Environment):
     pass
 
   def observation_spec(self):
-    return specs.Array(shape=(2,), dtype=np.float)
+    return specs.Array(shape=(2,), dtype=float)
 
 
 class PixelsTest(parameterized.TestCase):
